//-*-Mode: C++;-*-

#ifndef CGrantEdit_included
#define CGrantEdit_included

#include <qlist.h>
#include <qlined.h>

#include "granteditdata.h"
#include "PatternPair.h"
#include "stringlist.h"

class CGrantEdit : public CGrantEditData
{
    Q_OBJECT
public:
    CGrantEdit(QWidget* parent = NULL,const char* name = NULL);
    virtual ~CGrantEdit();
    void set_entries(PatternList*Patterns,stringlist*titles);
    PatternList*get_entries();
private:
    PatternList* OrigPatterns;
    int EditCounts;
    QList<QLineEdit>*WidgetList;
    void set_yesno(const char*name,QCheckBox*box,PatternList*pats);
private slots:
    void change_focus();
};
#endif // CGrantEdit_included
